@@ -99,34 +99,34 @@ class XTSConnectV2(XTSCommon):
     # URIs to various calls
     _routes: dict[str, str] = {
         # Host End points
-        "hostlookup": "/hostlookup",
-        "host.user.session": "/user/session",
+        "hostlookup": "/interactive/hostlookup",
+        "host.user.session": "/interactive/user/session",
         # Interactive API endpoints
         "interactive.prefix": "interactive",
-        "user.login": "/user/session",
-        "user.logout": "/user/session",
-        "user.profile": "/user/profile",
-        "user.balance": "/user/balance",
-        "orders": "/orders",
-        "trades": "/orders/trades",
-        "order.status": "/orders",
-        "order.place": "/orders",
-        "bracketorder.place": "/orders/bracket",
-        "bracketorder.modify": "/orders/bracket",
-        "bracketorder.cancel": "/orders/bracket",
-        "order.place.cover": "/orders/cover",
-        "order.exit.cover": "/orders/cover",
-        "order.modify": "/orders",
-        "order.cancel": "/orders",
-        "order.cancelall": "/orders/cancelall",
-        "order.history": "/orders",
-        "portfolio.positions": "/portfolio/positions",
-        "portfolio.holdings": "/portfolio/holdings",
-        "portfolio.positions.convert": "/portfolio/positions/convert",
-        "portfolio.squareoff": "/portfolio/squareoff",
-        "portfolio.dealerpositions": "/portfolio/dealerpositions",
-        "order.dealer.status": "/orders/dealerorderbook",
-        "dealer.trades": "/orders/dealertradebook",
+        "user.login": "/interactive/user/session",
+        "user.logout": "/interactive/user/session",
+        "user.profile": "/interactive/user/profile",
+        "user.balance": "/interactive/user/balance",
+        "orders": "/or/interactiveders",
+        "trades": "/or/interactiveders/trades",
+        "order.status": "/interactive/orders",
+        "order.place": "/interactive/orders",
+        "bracketorder.place": "/interactive/orders/bracket",
+        "bracketorder.modify": "/interactive/orders/bracket",
+        "bracketorder.cancel": "/interactive/orders/bracket",
+        "order.place.cover": "/interactive/orders/cover",
+        "order.exit.cover": "/interactive/orders/cover",
+        "order.modify": "/interactive/orders",
+        "order.cancel": "/interactive/orders",
+        "order.cancelall": "/interactive/orders/cancelall",
+        "order.history": "/interactive/orders",
+        "portfolio.positions": "/interactive/portfolio/positions",
+        "portfolio.holdings": "/interactive/portfolio/holdings",
+        "portfolio.positions.convert": "/interactive/portfolio/positions/convert",
+        "portfolio.squareoff": "/interactive/portfolio/squareoff",
+        "portfolio.dealerpositions": "/interactive/portfolio/dealerpositions",
+        "order.dealer.status": "/interactive/orders/dealerorderbook",
+        "dealer.trades": "/interactive/orders/dealertradebook",
         # Market API endpoints
         "marketdata.prefix": "apibinarymarketdata",
         "market.login": "/apibinarymarketdata/auth/login",
@@ -815,6 +815,8 @@ class XTSConnectV2(XTSCommon):
         url = urljoin(self.root, uri)
         headers: dict[str, str] = {}
 
+        print(url)
+
         if self.token:
             # set authorization header
             headers.update(
